        function getT(rr,cc){
       if(rr==3 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260616 a 12</strong> UTC HH+192 (rango:180-204)<br><strong>control +<br>EPS</strong>';}
       if(rr==3 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260616 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>1</strong> representante: <strong>6</strong> miembros: 21 <strong>control</strong><br>0,1,6,7,9,12,16,17,20,22,24,25,26,29,30,31,42,45,46,47,49';}
       if(rr==3 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260616 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>2</strong> representante: <strong>35</strong> miembros: 18 <br>2,4,5,8,10,15,21,28,32,33,35,36,37,39,40,41,48,50';}
       if(rr==3 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260616 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>3</strong> representante: <strong>23</strong> miembros: 12 <br>3,11,13,14,18,19,23,27,34,38,43,44';}
       if(rr==17 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260616 a 12</strong> UTC HH+192 (rango:180-204)<br><strong>control +<br>EPS</strong>';}
       if(rr==17 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260616 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>1</strong> representante: <strong>6</strong> miembros: 21 <strong>control</strong><br>0,1,6,7,9,12,16,17,20,22,24,25,26,29,30,31,42,45,46,47,49';}
       if(rr==17 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260616 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>2</strong> representante: <strong>35</strong> miembros: 18 <br>2,4,5,8,10,15,21,28,32,33,35,36,37,39,40,41,48,50';}
       if(rr==17 && cc==3){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260616 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>3</strong> representante: <strong>23</strong> miembros: 12 <br>3,11,13,14,18,19,23,27,34,38,43,44';}
       if(rr==19 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 2 mm</strong><br><br><strong>20260616 a 12</strong> UTC HH+192 (rango:180-204)<br><strong>control +<br>EPS</strong>';}
       if(rr==19 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 2 mm</strong><br><br><strong>20260616 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>1</strong> representante: <strong>6</strong> miembros: 21 <strong>control</strong><br>0,1,6,7,9,12,16,17,20,22,24,25,26,29,30,31,42,45,46,47,49';}
       if(rr==19 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 2 mm</strong><br><br><strong>20260616 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>2</strong> representante: <strong>35</strong> miembros: 18 <br>2,4,5,8,10,15,21,28,32,33,35,36,37,39,40,41,48,50';}
       if(rr==19 && cc==3){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 2 mm</strong><br><br><strong>20260616 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>3</strong> representante: <strong>23</strong> miembros: 12 <br>3,11,13,14,18,19,23,27,34,38,43,44';}
       if(rr==20 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 5 mm</strong><br><br><strong>20260616 a 12</strong> UTC HH+192 (rango:180-204)<br><strong>control +<br>EPS</strong>';}
       if(rr==20 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 5 mm</strong><br><br><strong>20260616 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>1</strong> representante: <strong>6</strong> miembros: 21 <strong>control</strong><br>0,1,6,7,9,12,16,17,20,22,24,25,26,29,30,31,42,45,46,47,49';}
       if(rr==20 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 5 mm</strong><br><br><strong>20260616 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>2</strong> representante: <strong>35</strong> miembros: 18 <br>2,4,5,8,10,15,21,28,32,33,35,36,37,39,40,41,48,50';}
       if(rr==20 && cc==3){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 5 mm</strong><br><br><strong>20260616 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>3</strong> representante: <strong>23</strong> miembros: 12 <br>3,11,13,14,18,19,23,27,34,38,43,44';}
       if(rr==21 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 10 mm</strong><br><br><strong>20260616 a 12</strong> UTC HH+192 (rango:180-204)<br><strong>control +<br>EPS</strong>';}
       if(rr==21 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 10 mm</strong><br><br><strong>20260616 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>1</strong> representante: <strong>6</strong> miembros: 21 <strong>control</strong><br>0,1,6,7,9,12,16,17,20,22,24,25,26,29,30,31,42,45,46,47,49';}
       if(rr==21 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 10 mm</strong><br><br><strong>20260616 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>2</strong> representante: <strong>35</strong> miembros: 18 <br>2,4,5,8,10,15,21,28,32,33,35,36,37,39,40,41,48,50';}
       if(rr==21 && cc==3){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 10 mm</strong><br><br><strong>20260616 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>3</strong> representante: <strong>23</strong> miembros: 12 <br>3,11,13,14,18,19,23,27,34,38,43,44';}
       if(rr==22 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 20 mm</strong><br><br><strong>20260616 a 12</strong> UTC HH+192 (rango:180-204)<br><strong>control +<br>EPS</strong>';}
       if(rr==22 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 20 mm</strong><br><br><strong>20260616 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>1</strong> representante: <strong>6</strong> miembros: 21 <strong>control</strong><br>0,1,6,7,9,12,16,17,20,22,24,25,26,29,30,31,42,45,46,47,49';}
       if(rr==22 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 20 mm</strong><br><br><strong>20260616 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>2</strong> representante: <strong>35</strong> miembros: 18 <br>2,4,5,8,10,15,21,28,32,33,35,36,37,39,40,41,48,50';}
       if(rr==22 && cc==3){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 20 mm</strong><br><br><strong>20260616 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>3</strong> representante: <strong>23</strong> miembros: 12 <br>3,11,13,14,18,19,23,27,34,38,43,44';}
}
