        function getT(rr,cc){
       if(rr==6 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260616 a 12</strong> UTC HH+192 (rango:180-204)<br><strong>control +<br>EPS</strong>';}
       if(rr==6 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260616 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>1</strong> representante: <strong>6</strong> miembros: 21 <strong>control</strong><br>0,1,6,7,9,12,16,17,20,22,24,25,26,29,30,31,42,45,46,47,49';}
       if(rr==6 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260616 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>2</strong> representante: <strong>35</strong> miembros: 18 <br>2,4,5,8,10,15,21,28,32,33,35,36,37,39,40,41,48,50';}
       if(rr==6 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260616 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>3</strong> representante: <strong>23</strong> miembros: 12 <br>3,11,13,14,18,19,23,27,34,38,43,44';}
       if(rr==29 && cc==0){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260616 a 12</strong> UTC HH+192 (rango:180-204)<br><strong>control +<br>EPS</strong>';}
       if(rr==29 && cc==1){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260616 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>1</strong> representante: <strong>6</strong> miembros: 21 <strong>control</strong><br>0,1,6,7,9,12,16,17,20,22,24,25,26,29,30,31,42,45,46,47,49';}
       if(rr==29 && cc==2){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260616 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>2</strong> representante: <strong>35</strong> miembros: 18 <br>2,4,5,8,10,15,21,28,32,33,35,36,37,39,40,41,48,50';}
       if(rr==29 && cc==3){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260616 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>3</strong> representante: <strong>23</strong> miembros: 12 <br>3,11,13,14,18,19,23,27,34,38,43,44';}
       if(rr==30 && cc==0){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260616 a 12</strong> UTC HH+192 (rango:180-204)<br><strong>control +<br>EPS</strong>';}
       if(rr==30 && cc==1){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260616 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>1</strong> representante: <strong>6</strong> miembros: 21 <strong>control</strong><br>0,1,6,7,9,12,16,17,20,22,24,25,26,29,30,31,42,45,46,47,49';}
       if(rr==30 && cc==2){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260616 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>2</strong> representante: <strong>35</strong> miembros: 18 <br>2,4,5,8,10,15,21,28,32,33,35,36,37,39,40,41,48,50';}
       if(rr==30 && cc==3){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260616 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>3</strong> representante: <strong>23</strong> miembros: 12 <br>3,11,13,14,18,19,23,27,34,38,43,44';}
       if(rr==31 && cc==0){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260616 a 12</strong> UTC HH+192 (rango:180-204)<br><strong>control +<br>EPS</strong>';}
       if(rr==31 && cc==1){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260616 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>1</strong> representante: <strong>6</strong> miembros: 21 <strong>control</strong><br>0,1,6,7,9,12,16,17,20,22,24,25,26,29,30,31,42,45,46,47,49';}
       if(rr==31 && cc==2){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260616 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>2</strong> representante: <strong>35</strong> miembros: 18 <br>2,4,5,8,10,15,21,28,32,33,35,36,37,39,40,41,48,50';}
       if(rr==31 && cc==3){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260616 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>3</strong> representante: <strong>23</strong> miembros: 12 <br>3,11,13,14,18,19,23,27,34,38,43,44';}
       if(rr==32 && cc==0){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260616 a 12</strong> UTC HH+192 (rango:180-204)<br><strong>control +<br>EPS</strong>';}
       if(rr==32 && cc==1){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260616 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>1</strong> representante: <strong>6</strong> miembros: 21 <strong>control</strong><br>0,1,6,7,9,12,16,17,20,22,24,25,26,29,30,31,42,45,46,47,49';}
       if(rr==32 && cc==2){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260616 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>2</strong> representante: <strong>35</strong> miembros: 18 <br>2,4,5,8,10,15,21,28,32,33,35,36,37,39,40,41,48,50';}
       if(rr==32 && cc==3){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260616 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>3</strong> representante: <strong>23</strong> miembros: 12 <br>3,11,13,14,18,19,23,27,34,38,43,44';}
       if(rr==33 && cc==0){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260616 a 12</strong> UTC HH+192 (rango:180-204)<br><strong>control +<br>EPS</strong>';}
       if(rr==33 && cc==1){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260616 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>1</strong> representante: <strong>6</strong> miembros: 21 <strong>control</strong><br>0,1,6,7,9,12,16,17,20,22,24,25,26,29,30,31,42,45,46,47,49';}
       if(rr==33 && cc==2){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260616 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>2</strong> representante: <strong>35</strong> miembros: 18 <br>2,4,5,8,10,15,21,28,32,33,35,36,37,39,40,41,48,50';}
       if(rr==33 && cc==3){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260616 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>3</strong> representante: <strong>23</strong> miembros: 12 <br>3,11,13,14,18,19,23,27,34,38,43,44';}
}
